Layer
=====

.. currentmodule:: wwt_data_formats.layers

.. autoclass:: Layer
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Layer.id
      ~Layer.layer_type
      ~Layer.name
      ~Layer.opacity
      ~Layer.reference_frame

   .. rubric:: Attributes Documentation

   .. autoattribute:: id
   .. autoattribute:: layer_type
   .. autoattribute:: name
   .. autoattribute:: opacity
   .. autoattribute:: reference_frame
